#!/usr/bin/env python
# -*- coding: utf-8 -*-

#   _______   _____   _____    _
#  |__   __| |_   _| |  __ \  | |
#     | |      | |   | |__) | | |
#     | |      | |   |  _  /  | |
#     | |     _| |_  | | \ \  | |____
#     |_|    |_____| |_|  \_\ |______|
#
# Copyright (C) 2018-2020 University of Oxford
# Part of the FMRIB Software Library (FSL)
# Author: Istvan N. Huszar


# FMRIB Software Library, Release 6.0.4 (c) 2020, The University of Oxford
# (the "Software")
# 
# The Software remains the property of the University of Oxford ("the
# University").
# 
# The Software is distributed "AS IS" under this Licence solely for
# non-commercial use in the hope that it will be useful, but in order
# that the University as a charitable foundation protects its assets for
# the benefit of its educational and research purposes, the University
# makes clear that no condition is made or to be implied, nor is any
# warranty given or to be implied, as to the accuracy of the Software,
# or that it will be suitable for any particular purpose or for use
# under any specific conditions. Furthermore, the University disclaims
# all responsibility for the use which is made of the Software. It
# further disclaims any liability for the outcomes arising from using
# the Software.
# 
# The Licensee agrees to indemnify the University and hold the
# University harmless from and against any and all claims, damages and
# liabilities asserted by third parties (including claims for
# negligence) which arise directly or indirectly from the use of the
# Software or the sale of any products based on the Software.
# 
# No part of the Software may be reproduced, modified, transmitted or
# transferred in any form or by any means, electronic or mechanical,
# without the express permission of the University. The permission of
# the University is not required if the said reproduction, modification,
# transmission or transference is done without financial return, the
# conditions of this Licence are imposed upon the receiver of the
# product, and all original and amended source code is included in any
# transmitted product. You may be held legally responsible for any
# copyright infringement that is caused or encouraged by your failure to
# abide by these terms and conditions.
# 
# You are not permitted under this Licence to use this Software
# commercially. Use for which any financial return is received shall be
# defined as commercial use, and includes (1) integration of all or part
# of the source code or the Software into a product for sale or license
# by or on behalf of Licensee to third parties or (2) use of the
# Software or any derivative of it for research with the final aim of
# developing software products for sale or license to a third party or
# (3) use of the Software or any derivative of it for research with the
# final aim of developing non-software products for sale or license to a
# third party, or (4) use of the Software to provide any service to an
# external organisation for which payment is received. If you are
# interested in using the Software commercially, please contact Oxford
# University Innovation ("OUI"), the technology transfer company of the
# University, to negotiate a licence. Contact details are:
# Innovation@innovation.ox.ac.uk quoting reference BS/9564.
# 


# DEVELOPMENT NOTES

"""
23-June-2020 Istvan N Huszar:
This is a legacy argument parser, that will be replaced with argparse in
future versions. Currently only the 'stripbg' uses this module.

"""


# DEPENDENCIES

import sys


def argexist(argv, subarg=False):
    """The argexist subroutine returns whether the given argument was specified
    via the command line. When subarg is True, the result will be False if the
    argument is found and it is supposed to have a subargument that is missing.
    """

    if argv in sys.argv:
        if subarg:
            if len(sys.argv)-1 > sys.argv.index(argv):
                if not sys.argv[sys.argv.index(argv)+1].startswith('-'):
                    return True
                else:
                    return False
            else:
                return False
        else:
            return True
    else:
        return False


def subarg(argv, default_value="", splitat=','):
    """The subarg subroutine returns the subargument list of a given argument,
    if its was specified via the command line. When the subargument is missing,
    a preset default value will be returned. Note that the return value is
    always a list."""

    if argexist(argv, subarg=True):
        arglist = []
        for arg in sys.argv[sys.argv.index(argv)+1:]:
            if not arg.startswith('-'):
                for p in arg.split(splitat):
                    arglist.append(p)
            else:
                break
        return arglist
    else:
        return str(default_value).split(splitat)


def confirmed_to_proceed(forceanswer=True):
    """Forces user input for continuing the execution of the program."""

    no = {'no', 'n'}
    if forceanswer:
        yes = {'yes', 'y', 'ye'}
    else:
        yes = {'yes', 'y', 'ye', ''}

    choice = input().lower()
    if choice in yes:
        return True
    elif choice in no:
        return False
    else:
        sys.stdout.write("Please respond with 'yes' or 'no': ")
        choice = confirmed_to_proceed()
        return choice
